import { Children, cloneElement, isValidElement } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import MoleculeTab from './components/MoleculeTab';
import withStateActiveTab from './hoc/withStateActiveTab';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var BASE_CLASS = "sui-MoleculeTabs";
var CLASS_SCROLLER = BASE_CLASS + "-scroller";
var CLASS_CONTENT = BASE_CLASS + "-content";
var TYPES = {
  HORIZONTAL: 'horizontal',
  VERTICAL: 'vertical',
  FULLWIDTH: 'fullWidth'
};
var VARIANTS = {
  HIGHLIGHTED: 'highlighted',
  CLASSIC: 'classic'
};

var MoleculeTabs = function MoleculeTabs(_ref) {
  var variant = _ref.variant,
      type = _ref.type,
      children = _ref.children,
      onChange = _ref.onChange;
  var CLASS_VARIANT = BASE_CLASS + "--" + variant;
  var CLASS_TYPE = BASE_CLASS + "--" + type;
  var className = cx(BASE_CLASS, CLASS_VARIANT, CLASS_TYPE);
  var extendedChildren = Children.toArray(children).filter(function (child) {
    return /*#__PURE__*/isValidElement(child);
  }).map(function (child, index) {
    var numTab = index + 1;
    return /*#__PURE__*/cloneElement(child, {
      onChange: onChange,
      numTab: numTab
    });
  });
  var activeTabContent = Children.toArray(children).reduce(function (activeContent, child) {
    if (child) {
      var _child$props = child.props,
          childrenChild = _child$props.children,
          active = _child$props.active;
      return active ? childrenChild : activeContent;
    }
  }, null);
  return /*#__PURE__*/_jsxs("div", {
    className: className,
    children: [/*#__PURE__*/_jsx("ul", {
      className: CLASS_SCROLLER,
      children: extendedChildren
    }), activeTabContent ? /*#__PURE__*/_jsx("div", {
      className: CLASS_CONTENT,
      children: activeTabContent
    }) : null]
  });
};

MoleculeTabs.displayName = 'MoleculeTabs';
MoleculeTabs.defaultProps = {
  variant: VARIANTS.CLASSIC,
  type: TYPES.HORIZONTAL,
  onChange: function onChange() {}
};
var MoleculeTabsWithStateActive = withStateActiveTab(MoleculeTabs);
MoleculeTabsWithStateActive.displayName = MoleculeTabs.displayName;
export default MoleculeTabsWithStateActive;
export { MoleculeTabs, MoleculeTab, TYPES as moleculeTabsTypes, VARIANTS as moleculeTabsVariants };